import * as i0 from '@angular/core';
import { InjectionToken, NgModule, signal, Injectable, Inject, EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, ViewChild, Output } from '@angular/core';
import { ENTER, COMMA } from '@angular/cdk/keycodes';
import * as i10 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';
import * as i2 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i8 from '@angular/material/slide-toggle';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import * as i3 from '@angular/platform-browser';
import { DOCUMENT, NgStyle, NgIf, NgFor, DatePipe, AsyncPipe, CommonModule } from '@angular/common';
import * as i7 from '@angular/material/badge';
import { MatBadgeModule } from '@angular/material/badge';
import * as i4 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i9 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i6 from '@angular/material/menu';
import { MatMenuModule } from '@angular/material/menu';
import * as i5 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatInputModule } from '@angular/material/input';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';

/**
 * Default declared color
 */
const COLOR = {
    WHITE: '#ffffff',
};
/**
 * Color palette
 *
 * @namespace COLOR_PALETTE
 * @property {string[]} DEFAULT - Default color palette
 * @property {string[]} FLAT - Flat design color palette
 */
const COLOR_PALETTE = {
    DEFAULT: [
        '#F44336',
        '#E91E63',
        '#9C27B0',
        '#673AB7',
        '#3F51B5',
        '#2196F3',
        '#03A9F4',
        '#00BCD4',
        '#009688',
        '#4CAF50',
        '#8BC34A',
        '#CDDC39',
        '#FFEB3B',
        '#FFC107',
        '#FF9800',
        '#FF5722',
    ],
    FLAT: [
        '#FFC312',
        '#F79F1F',
        '#EE5A24',
        '#EA2027',
        '#C4E538',
        '#A3CB38',
        '#009432',
        '#006266',
        '#12CBC4',
        '#1289A7',
        '#0652DD',
        '#1B1464',
        '#FDA7DF',
        '#D980FA',
        '#9980FA',
        '#5758BB',
        '#ED4C67',
        '#B53471',
        '#833471',
        '#6F1E51',
    ],
};

const version = '1.0.0';

/**
 * Multi Keywords Highlighter Constants
 */
class MultiKeywordsHighlighterConstants {
    static { this.APP_NAME = 'Multi keywords highlighter'; }
    static { this.APP_VERSION = version || '~0.0.0'; }
    static { this.COPYRIGHT = {
        AUTHOR: 'Amfrontender',
        CONTACT: 'https://github.com/Amfrontender',
    }; }
    static { this.KEYWORDS_PLACEHOLDER = 'Keywords...'; }
    static { this.REMOVABLE = true; }
    static { this.MIN_WIDTH = 340; }
    static { this.ENABLE_TOGGLE_LABEL = false; }
    static { this.ENABLE_HIGHLIGHTER_TOOLTIP = 'Enable highlighter'; }
    static { this.ENABLE_COLOR_PALETTE = false; }
    static { this.INIT_KEYWORDS = true; }
    static { this.HIGHLIGHTER = {
        ON: 'ON',
        OFF: 'OFF',
    }; }
    static { this.HIGHLIGHT_CLASS = 'mh-text-highlighted'; }
    static { this.MIN_SEARCH_LENGTH = 2; }
    static { this.APP_ROOT = 'app-root'; }
}
/**
 * Name Space
 */
const NAME_SPACE = {
    KEYWORDS: 'MH_KEYWORDS',
    HIGHLIGHTED: 'MH_HIGHLIGHTED',
    HIGHLIGHT_STATUS: 'MH_HIGHLIGHT_STATUS',
};
var MATERIAL_COLOR;
(function (MATERIAL_COLOR) {
    MATERIAL_COLOR["PRIMARY"] = "primary";
    MATERIAL_COLOR["ACCENT"] = "accent";
    MATERIAL_COLOR["WARN"] = "warn";
})(MATERIAL_COLOR || (MATERIAL_COLOR = {}));
var LABEL_POSITION;
(function (LABEL_POSITION) {
    LABEL_POSITION["BEFORE"] = "before";
    LABEL_POSITION["AFTER"] = "after";
})(LABEL_POSITION || (LABEL_POSITION = {}));

/**
 * Default configuration
 *
 * @see MultiKeywordsHighlighterConfig
 */
const defaultConfig = {
    appRoot: MultiKeywordsHighlighterConstants.APP_ROOT,
    caseSensitive: false,
    chipIconColor: COLOR.WHITE,
    chipTextColor: COLOR.WHITE,
    colorPalette: COLOR_PALETTE.DEFAULT,
    customNodeFilter: null,
    enableColorPalette: MultiKeywordsHighlighterConstants.ENABLE_COLOR_PALETTE,
    enableHighlighterTooltip: MultiKeywordsHighlighterConstants.ENABLE_HIGHLIGHTER_TOOLTIP,
    enableToggleLabel: MultiKeywordsHighlighterConstants.ENABLE_TOGGLE_LABEL,
    highlightClass: MultiKeywordsHighlighterConstants.HIGHLIGHT_CLASS,
    initKeywords: MultiKeywordsHighlighterConstants.INIT_KEYWORDS,
    keywordsPlaceholder: MultiKeywordsHighlighterConstants.KEYWORDS_PLACEHOLDER,
    linkToCopyright: true,
    minSearchLength: MultiKeywordsHighlighterConstants.MIN_SEARCH_LENGTH,
    minWidth: MultiKeywordsHighlighterConstants.MIN_WIDTH,
    removable: MultiKeywordsHighlighterConstants.REMOVABLE,
    themeColor: MATERIAL_COLOR.PRIMARY,
    toggleLabelPosition: LABEL_POSITION.AFTER,
};

/**
 * Static library configuration
 *
 * @namespace LibConfig
 * @property {string} APP_NAME - Library name
 * @property {string} APP_VERSION - Library version
 * @property {string} COPYRIGHT_AUTHOR - Library author name
 * @property {string} COPYRIGHT_CONTACT - Library author contact
 */
class LibConfig {
    static { this.APP_NAME = MultiKeywordsHighlighterConstants.APP_NAME; }
    static { this.APP_VERSION = MultiKeywordsHighlighterConstants.APP_VERSION; }
    static { this.COPYRIGHT_AUTHOR = MultiKeywordsHighlighterConstants.COPYRIGHT.AUTHOR; }
    static { this.COPYRIGHT_CONTACT = MultiKeywordsHighlighterConstants.COPYRIGHT.CONTACT; }
}

/**
 * MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN
 */
const MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN = new InjectionToken('MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN');

/**
 * Material Icon: [highlight](https://material.io/resources/icons/?search=highlight&icon=color_lens&style=baseline)
 */
const ICON_HIGHLIGHT = `<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><g><path d="M6,14l3,3v5h6v-5l3-3V9H6V14z M11,2h2v3h-2V2z M3.5,5.88l1.41-1.41l2.12,2.12L5.62,8L3.5,5.88z M16.96,6.59l2.12-2.12 l1.41,1.41L18.38,8L16.96,6.59z"/></g></g></g></svg>`;
/**
 * Material Icon: [color_lens](https://material.io/resources/icons/?search=color_lens&icon=color_lens&style=baseline)
 */
const ICON_COLOR_LENS = `<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M12 3c-4.97 0-9 4.03-9 9s4.03 9 9 9c.83 0 1.5-.67 1.5-1.5 0-.39-.15-.74-.39-1.01-.23-.26-.38-.61-.38-.99 0-.83.67-1.5 1.5-1.5H16c2.76 0 5-2.24 5-5 0-4.42-4.03-8-9-8zm-5.5 9c-.83 0-1.5-.67-1.5-1.5S5.67 9 6.5 9 8 9.67 8 10.5 7.33 12 6.5 12zm3-4C8.67 8 8 7.33 8 6.5S8.67 5 9.5 5s1.5.67 1.5 1.5S10.33 8 9.5 8zm5 0c-.83 0-1.5-.67-1.5-1.5S13.67 5 14.5 5s1.5.67 1.5 1.5S15.33 8 14.5 8zm3 4c-.83 0-1.5-.67-1.5-1.5S16.67 9 17.5 9s1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"/></svg>`;
/**
 * Material Icon: [clear](https://fonts.google.com/icons?selected=Material%20Icons%20Outlined%3Aclear%3A)
 */
const ICON_CLEAR = `<svg xmlns="http://www.w3.org/2000/svg" height="24px" viewBox="0 0 24 24" width="24px"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41z"/></svg>`;

class MaterialComponentsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: MaterialComponentsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.8", ngImport: i0, type: MaterialComponentsModule, imports: [MatIconModule,
            MatBadgeModule,
            MatButtonModule,
            MatChipsModule,
            MatFormFieldModule,
            MatInputModule,
            MatMenuModule,
            MatSlideToggleModule,
            MatTooltipModule], exports: [MatIconModule,
            MatBadgeModule,
            MatButtonModule,
            MatChipsModule,
            MatFormFieldModule,
            MatInputModule,
            MatMenuModule,
            MatSlideToggleModule,
            MatTooltipModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: MaterialComponentsModule, imports: [MatIconModule,
            MatBadgeModule,
            MatButtonModule,
            MatChipsModule,
            MatFormFieldModule,
            MatInputModule,
            MatMenuModule,
            MatSlideToggleModule,
            MatTooltipModule, MatIconModule,
            MatBadgeModule,
            MatButtonModule,
            MatChipsModule,
            MatFormFieldModule,
            MatInputModule,
            MatMenuModule,
            MatSlideToggleModule,
            MatTooltipModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: MaterialComponentsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        MatIconModule,
                        MatBadgeModule,
                        MatButtonModule,
                        MatChipsModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatMenuModule,
                        MatSlideToggleModule,
                        MatTooltipModule,
                    ],
                    exports: [
                        MatIconModule,
                        MatBadgeModule,
                        MatButtonModule,
                        MatChipsModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatMenuModule,
                        MatSlideToggleModule,
                        MatTooltipModule,
                    ],
                }]
        }] });

class NgxMultiKeywordsHighlighterService {
    constructor(document, multiKeywordsHighlighterConfig) {
        this.document = document;
        this.multiKeywordsHighlighterConfig = multiKeywordsHighlighterConfig;
        this.localKeywords$ = signal([]);
        this.highlightedStatus$ = signal(false);
        this.keywordSequence$ = signal(0);
    }
    get config() {
        return Object.assign(defaultConfig, this.multiKeywordsHighlighterConfig);
    }
    get localKeywords() {
        return this.localKeywords$();
    }
    get highlightedStatusText() {
        return this.highlightedStatus$()
            ? MultiKeywordsHighlighterConstants.HIGHLIGHTER.ON
            : MultiKeywordsHighlighterConstants.HIGHLIGHTER.OFF;
    }
    get isHighlight() {
        return this.highlightedStatus$();
    }
    get rootNode() {
        return (this.document.body.getElementsByTagName(defaultConfig.appRoot)[0] ||
            this.document.body);
    }
    /**
     * Toggle Highlight Status
     */
    toggleHighlightStatus(status) {
        return this.highlightedStatus$.set(status);
    }
    /**
     * Add Keyword
     */
    addKeyword(keyword) {
        const tempKeywordList = this.localKeywords$();
        let currentSequence = this.keywordSequence$();
        if (this.isValidKeyword(keyword)) {
            tempKeywordList.push({
                ...keyword,
                id: (currentSequence += 1),
            });
            this.keywordSequence$.set(currentSequence);
            if (this.isHighlight) {
                this.hightlightKeyword(keyword);
            }
            this.localKeywords$.set(tempKeywordList);
        }
    }
    /**
     * Check keyword is not empty and not duplicated
     */
    isValidKeyword(keyword) {
        return !this.isEmpty(keyword) && !this.isDuplicated(keyword);
    }
    /**
     * Check keyword is not empty
     */
    isEmpty(keyword) {
        return (keyword.name || '').trim().length <= 0;
    }
    /**
     * Check keyword is not duplicated
     */
    isDuplicated(keyword) {
        return this.localKeywords$().some((item) => item.name === keyword.name);
    }
    /**
     * Remove a Keyword
     */
    removeKeyword(keyword) {
        const tempKeywordList = this.localKeywords$();
        const index = tempKeywordList.indexOf(keyword);
        if (index >= 0) {
            tempKeywordList.splice(index, 1);
            this.deHightlightKeyword(keyword);
            this.localKeywords$.set(tempKeywordList);
        }
    }
    /**
     * Toggle Highlighter and highlight keywords or de-highlight keywords
     */
    toggleHighlighter() {
        this.isHighlight
            ? this.hightlightAllKeywords()
            : this.deHightlightAllKeywords();
    }
    /**
     * Highlight all keywords
     */
    hightlightAllKeywords() {
        const allKeywords = this.localKeywords$();
        allKeywords.forEach((keyword) => {
            this.hightlightKeyword(keyword);
        });
    }
    /**
     * De-highlight all keywords
     */
    deHightlightAllKeywords() {
        const allKeywords = this.localKeywords$();
        allKeywords.forEach((keyword) => {
            this.deHightlightKeyword(keyword);
        });
    }
    /**
     * Highlight a single keyword
     */
    hightlightKeyword(keyword) {
        if (!keyword || !keyword.name) {
            return;
        }
        const treeWalker = this.createTreeWorker(this.rootNode);
        let nextNode = null;
        const matchedNodes = [];
        // eslint-disable-next-line no-cond-assign
        while ((nextNode = treeWalker.nextNode())) {
            const nodeValue = nextNode.nodeValue;
            if (nextNode.nodeType === Node.TEXT_NODE &&
                nodeValue?.toLowerCase().indexOf(keyword.name.toLowerCase()) !== -1) {
                matchedNodes.push(nextNode);
            }
        }
        if (matchedNodes.length > 100) {
            console.warn('[Warn Message] Matched Too Many');
            return;
        }
        for (const iteratorNode of matchedNodes) {
            nextNode = iteratorNode;
            let parentNode = nextNode.parentNode;
            if (!parentNode) {
                parentNode = nextNode;
                parentNode.nodeValue = '';
            }
            else if (parentNode.className === defaultConfig.highlightClass) {
                // prevent duplicate highlighting
                continue;
            }
            let keywordParts;
            if (this.config.caseSensitive) {
                keywordParts = nextNode.data.split(new RegExp(`(${keyword.name})`));
            }
            else {
                keywordParts = nextNode.data.split(new RegExp(`(${keyword.name})`, 'i'));
            }
            const newNodes = this.createHighlightElements(keywordParts, keyword) || [];
            let insertNode;
            while ((insertNode = newNodes.shift())) {
                parentNode.insertBefore(insertNode, nextNode);
            }
            parentNode.removeChild(nextNode);
        }
    }
    createTreeWorker(rootNode) {
        return this.document.createTreeWalker(rootNode, NodeFilter.SHOW_TEXT, this.config.customNodeFilter);
    }
    /**
     * Create Highlight Elements
     */
    createHighlightElements(keywordParts, keyword) {
        const newElement = [];
        for (const iteratorPart of keywordParts) {
            if (!iteratorPart) {
                continue;
            }
            else if (this.isMatchedKeyword(iteratorPart, keyword)) {
                // create new element node to wrap selection
                const newNode = this.document.createElement('span');
                newNode.className = defaultConfig.highlightClass;
                newNode.innerText = iteratorPart;
                newNode.style.background = keyword.color;
                newNode.style.color = COLOR.WHITE;
                newElement.push(newNode);
            }
            else {
                // create new text node to place remaining text
                const newTextNode = document.createTextNode(iteratorPart);
                newElement.push(newTextNode);
            }
        }
        return newElement;
    }
    /**
     * De-highlight a single keyword
     */
    deHightlightKeyword(keyword) {
        const highlightedElements = document.querySelectorAll(`.${defaultConfig.highlightClass}`);
        highlightedElements.forEach((elm) => {
            const highlightedElmement = elm;
            const highlightedKeyword = highlightedElmement.textContent || '';
            if (this.isMatchedKeyword(highlightedKeyword, keyword)) {
                const parentNode = highlightedElmement.parentNode;
                const textNode = document.createTextNode(highlightedElmement.innerText);
                parentNode?.replaceChild(textNode.cloneNode(false), highlightedElmement);
                // call normalize to combine separated text nodes
                parentNode?.normalize();
            }
        });
    }
    /**
     * Check the input keyword is match with node text content
     */
    isMatchedKeyword(highlightedKeyword, keyword) {
        return ((!this.config.caseSensitive &&
            highlightedKeyword.toLowerCase() === keyword.name.toLowerCase()) ||
            (this.config.caseSensitive && highlightedKeyword === keyword.name));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterService, deps: [{ token: DOCUMENT }, { token: MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN]
                }] }] });

class NgxMultiKeywordsHighlighterComponent {
    constructor(mkhService, iconRegistry, sanitizer) {
        this.mkhService = mkhService;
        this.iconRegistry = iconRegistry;
        this.sanitizer = sanitizer;
        /**
         * Output event for initialized event
         * @returns boolean
         */
        this.initialized = new EventEmitter(false);
        /**
         * Output event for keywords list
         * @returns IKeyword[]
         */
        this.keywordListOutput = new EventEmitter();
        /**
         * Output event for highlighted status
         * @returns boolean
         */
        this.highlighted = new EventEmitter(false);
        /**
         * Output event for on Open Menu
         * @returns boolean
         */
        this.openMenu = new EventEmitter(false);
        /**
         * Output event for on Close Menu
         * @returns boolean
         */
        this.closeMenu = new EventEmitter(false);
        /**
         * Copyright year
         */
        this.currentYear = new Date();
        /**
         * Separator keys codes
         */
        this.separatorKeysCodes = [ENTER, COMMA];
        /**
         * Keyword quantity shows on badge
         */
        this.keywordQuantity$ = signal(0);
        iconRegistry.addSvgIconLiteral('highlight', sanitizer.bypassSecurityTrustHtml(ICON_HIGHLIGHT));
        iconRegistry.addSvgIconLiteral('color_lens', sanitizer.bypassSecurityTrustHtml(ICON_COLOR_LENS));
        iconRegistry.addSvgIconLiteral('clear', sanitizer.bypassSecurityTrustHtml(ICON_CLEAR));
    }
    ngOnInit() {
        this.initialized.emit(true);
    }
    /**
     * Copyright
     */
    get copyright() {
        return LibConfig.COPYRIGHT_AUTHOR;
    }
    /**
     * Copyright link
     */
    get copyrightLink() {
        return LibConfig.COPYRIGHT_CONTACT;
    }
    /**
     * Library name
     */
    get appName() {
        return LibConfig.APP_NAME;
    }
    /**
     * Library version
     */
    get appVersion() {
        return LibConfig.APP_VERSION;
    }
    /**
     * Library configuration
     */
    get config() {
        return this.mkhService.config;
    }
    /**
     * Highlighted stauts text
     */
    get highlightedStautsText$() {
        return this.mkhService.highlightedStatusText;
    }
    /**
     * Highlight status
     */
    get highlightStauts$() {
        return this.mkhService.highlightedStatus$();
    }
    /**
     * Keyword list
     */
    get keywordList$() {
        return this.mkhService.localKeywords$();
    }
    /**
     * Keyword counter
     */
    get keywordCount$() {
        return this.mkhService.localKeywords$().length;
    }
    /**
     * On keywords highlighter opened event
     */
    onOpened() {
        this.openMenu.emit(true);
    }
    /**
     * On keywords highlighter closed event
     */
    onClosed() {
        this.closeMenu.emit(true);
    }
    /**
     * On check the highlighter checkbox
     * @param event MatSlideToggleChange
     */
    onToggle(event) {
        this.mkhService.toggleHighlightStatus(event.checked);
        this.mkhService.toggleHighlighter();
        this.highlighted.emit(event.checked);
        // BUG: this.config is READONLY, Need to create a method to update the config.
        // event.checked
        //   ? (this.config.themeColor = MATERIAL_COLOR.ACCENT)
        //   : (this.config.themeColor = MATERIAL_COLOR.PRIMARY);
    }
    trackById(index, keyword) {
        return keyword?.id;
    }
    /**
     * Add a keyword
     * @param event MatChipInputEvent
     */
    addKeyword(event) {
        const chipInput = event.chipInput;
        const chipValue = event.value;
        if (chipValue) {
            const newKeyword = {
                name: chipValue.trim(),
                color: this.getRandomColor(),
                createdAt: new Date().toUTCString(),
            };
            this.mkhService.addKeyword(newKeyword);
            this.keywordListOutput.emit(this.mkhService.localKeywords);
            // Reset the input value
            if (chipInput) {
                chipInput.clear();
            }
        }
    }
    /**
     * Remove a keyword from the list
     * @param keyword Keyword to remove
     */
    removeKeyword(keyword) {
        this.mkhService.removeKeyword(keyword);
        this.keywordListOutput.emit(this.mkhService.localKeywords);
    }
    /**
     * Get a random color from the color palette
     */
    getRandomColor() {
        return this.config.colorPalette[Math.floor(Math.random() * this.config.colorPalette.length)];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterComponent, deps: [{ token: NgxMultiKeywordsHighlighterService }, { token: i2.MatIconRegistry }, { token: i3.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.0.8", type: NgxMultiKeywordsHighlighterComponent, isStandalone: true, selector: "mkh-multi-keywords-highlighter", outputs: { initialized: "initialized", keywordListOutput: "keywordListOutput", highlighted: "highlighted", openMenu: "openMenu", closeMenu: "closeMenu" }, viewQueries: [{ propertyName: "menuTrigger", first: true, predicate: ["menuTrigger"], descendants: true }], ngImport: i0, template: "<button\n  mat-icon-button\n  aria-hidden=\"false\"\n  aria-label=\"Multi keywords highlighter\"\n  [color]=\"config.themeColor\"\n  [matTooltip]=\"appName\"\n  [matMenuTriggerFor]=\"menu\"\n  (menuOpened)=\"onOpened()\"\n  (menuClosed)=\"onClosed()\"\n  #menuTrigger=\"matMenuTrigger\"\n  data-testid=\"highlight-keywords-button\"\n>\n  <mat-icon\n    id=\"mh-keyword-count\"\n    aria-hidden=\"false\"\n    aria-label=\"Keywords highlights icon\"\n    [matBadge]=\"keywordCount$\"\n    [matBadgeHidden]=\"keywordCount$ === 0\"\n    matBadgePosition=\"after\"\n    matBadgeColor=\"accent\"\n    svgIcon=\"highlight\"\n  ></mat-icon>\n</button>\n<mat-menu\n  backdropClass=\"mh-backdrop\"\n  class=\"mh-menu\"\n  #menu=\"matMenu\"\n  xPosition=\"before\"\n  yPosition=\"below\"\n>\n  <div\n    class=\"mh-panel\"\n    data-testid=\"highlight-keywords-panel\"\n    (click)=\"$event.stopPropagation()\"\n    [ngStyle]=\"{ minWidth: config.minWidth + 'px' }\"\n  >\n    <div class=\"mh-header mb-[10px]\">\n      <span class=\"mh-text\">\n        <span class=\"mh-app-name\">{{ appName }}</span>\n        <small class=\"mh-version mh-text-tint\">{{ appVersion }}</small>\n      </span>\n      <div class=\"mh-actions\">\n        <ng-container *ngIf=\"config.enableColorPalette\">\n          <button\n            mat-icon-button\n            aria-label=\"Color theme\"\n            [color]=\"config.themeColor\"\n            [matMenuTriggerFor]=\"colorMenu\"\n          >\n            <mat-icon svgIcon=\"color_lens\"></mat-icon>\n          </button>\n          <mat-menu\n            backdropClass=\"mh-backdrop\"\n            class=\"mh-color-palette-menu\"\n            #colorMenu=\"matMenu\"\n            xPosition=\"before\"\n            yPosition=\"below\"\n          >\n            <div (click)=\"$event.stopPropagation()\">\n              <!-- <lib-color-palette></lib-color-palette> -->\n            </div>\n          </mat-menu>\n        </ng-container>\n        <mat-slide-toggle\n          class=\"mh-toggle\"\n          [checked]=\"highlightStauts$\"\n          [matTooltip]=\"config.enableHighlighterTooltip\"\n          [labelPosition]=\"config.toggleLabelPosition\"\n          [color]=\"config.themeColor\"\n          (change)=\"onToggle($event)\"\n          ariaLabel=\"Toggle Highlighter\"\n          data-testid=\"highlight-keywords-slide-toggle\"\n        >\n          <ng-container *ngIf=\"config.enableToggleLabel\">\n            <span class=\"mh-text\">{{ highlightedStautsText$ }}</span>\n          </ng-container>\n        </mat-slide-toggle>\n      </div>\n    </div>\n    <div class=\"mh-body\">\n      <div class=\"mh-content\">\n        <mat-form-field class=\"mh-keyword-list\" appearance=\"fill\">\n          <mat-label>{{ config.keywordsPlaceholder }}</mat-label>\n          <mat-chip-grid aria-label=\"Enter keywords\" #keywordChipList>\n            <mat-chip-row\n              *ngFor=\"let keyword of keywordList$; trackBy: trackById\"\n              selectable=\"true\"\n              [removable]=\"config.removable\"\n              (removed)=\"removeKeyword(keyword)\"\n              [ngStyle]=\"{ 'background-color': keyword?.color }\"\n            >\n              <span\n                matTooltip=\"{{\n                  keyword.name.length >= 36 ? keyword.name : null\n                }}\"\n                class=\"mh-keyword-list-text\"\n                [ngStyle]=\"{ color: config.chipTextColor }\"\n              >\n                {{ keyword.name }}\n              </span>\n              <mat-icon\n                svgIcon=\"clear\"\n                matTooltip=\"Clear\"\n                matChipRemove\n                *ngIf=\"config.removable\"\n                [ngStyle]=\"{ fill: config.chipIconColor }\"\n              >\n              </mat-icon>\n            </mat-chip-row>\n          </mat-chip-grid>\n          <input\n            data-testid=\"mkh-keywords-input\"\n            placeholder=\"{{ config.keywordsPlaceholder }}\"\n            [matChipInputFor]=\"keywordChipList\"\n            [matChipInputSeparatorKeyCodes]=\"separatorKeysCodes\"\n            [matChipInputAddOnBlur]=\"true\"\n            (matChipInputTokenEnd)=\"addKeyword($event)\"\n          />\n        </mat-form-field>\n      </div>\n      <div class=\"mh-footer\">\n        <span class=\"mh-text mh-text-tint\"\n          >Separate by comma [,] or enter key</span\n        >\n        <span class=\"mh-text mh-text-tint\">\n          <ng-container *ngIf=\"config.linkToCopyright; else normalCopyright\">\n            &copy;\n            <a\n              [href]=\"copyrightLink\"\n              class=\"mh-copyright underline\"\n              target=\"_blank\"\n              >{{ copyright }}</a\n            >\n          </ng-container>\n          <ng-template #normalCopyright>\n            <span class=\"mh-copyright\">&copy; {{ copyright }}</span>\n          </ng-template>\n          <span class=\"mh-date\">{{ currentYear | date: 'yyyy' }}</span>\n        </span>\n      </div>\n    </div>\n  </div>\n</mat-menu>\n", styles: ["[role=menu].mat-mdc-menu-panel.mh-menu{min-width:100%;max-width:100%;padding-left:1rem;padding-right:1rem;padding-top:0;padding-bottom:.25rem}.mh-text{font-size:.75rem;line-height:1rem}.mh-text-tint{color:#999}.mh-text-highlighted{display:inline-block;border-radius:3px;padding:0 5px;text-decoration-line:none;--tw-shadow: 0 4px 6px -1px rgb(0 0 0 / .1), 0 2px 4px -2px rgb(0 0 0 / .1);--tw-shadow-colored: 0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.mh-app-name{margin-right:.25rem}.mh-version{font-size:.75rem;line-height:1rem}.mh-panel{display:flex;flex-direction:column}.mh-keyword-list{width:100%}.mh-header{display:flex;flex-direction:row;align-items:center;justify-content:space-between}.mh-actions{display:flex;flex-direction:row;align-items:center;justify-content:flex-end}.mh-body{display:flex;flex-direction:column}.mh-footer{display:flex;align-items:center;justify-content:space-between}.mh-date{margin-left:.25rem}.mh-toggle[ng-reflect-label-position=before] .mh-text{margin-right:.75rem}.mh-toggle[ng-reflect-label-position=after] .mh-text{margin-left:.75rem}a.mh-copyright{color:#999;text-decoration-line:none}a.mh-copyright.underline,a:hover{text-decoration-line:underline}aa.mh-copyright:hover{text-decoration-line:underline}.mat-mdc-chip-input.mat-mdc-form-field-input-control{margin-left:0}.mat-mdc-chip-set .mat-mdc-standard-chip:not(.mdc-evolution-chip--selected) .mdc-evolution-chip__action--primary:before{border-width:0px}\n"], dependencies: [{ kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i4.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "ngmodule", type: MatTooltipModule }, { kind: "directive", type: i5.MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "ngmodule", type: MatMenuModule }, { kind: "component", type: i6.MatMenu, selector: "mat-menu", inputs: ["backdropClass", "aria-label", "aria-labelledby", "aria-describedby", "xPosition", "yPosition", "overlapTrigger", "hasBackdrop", "class", "classList"], outputs: ["closed", "close"], exportAs: ["matMenu"] }, { kind: "directive", type: i6.MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", inputs: ["mat-menu-trigger-for", "matMenuTriggerFor", "matMenuTriggerData", "matMenuTriggerRestoreFocus"], outputs: ["menuOpened", "onMenuOpen", "menuClosed", "onMenuClose"], exportAs: ["matMenuTrigger"] }, { kind: "ngmodule", type: MatIconModule }, { kind: "component", type: i2.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "ngmodule", type: MatBadgeModule }, { kind: "directive", type: i7.MatBadge, selector: "[matBadge]", inputs: ["matBadgeColor", "matBadgeOverlap", "matBadgeDisabled", "matBadgePosition", "matBadge", "matBadgeDescription", "matBadgeSize", "matBadgeHidden"] }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: MatSlideToggleModule }, { kind: "component", type: i8.MatSlideToggle, selector: "mat-slide-toggle", inputs: ["disabled", "disableRipple", "color", "tabIndex", "name", "id", "labelPosition", "aria-label", "aria-labelledby", "aria-describedby", "required", "checked", "hideIcon"], outputs: ["change", "toggleChange"], exportAs: ["matSlideToggle"] }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "component", type: i9.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i9.MatLabel, selector: "mat-label" }, { kind: "ngmodule", type: MatChipsModule }, { kind: "component", type: i10.MatChipGrid, selector: "mat-chip-grid", inputs: ["tabIndex", "disabled", "placeholder", "required", "value", "errorStateMatcher"], outputs: ["change", "valueChange"] }, { kind: "directive", type: i10.MatChipInput, selector: "input[matChipInputFor]", inputs: ["matChipInputFor", "matChipInputAddOnBlur", "matChipInputSeparatorKeyCodes", "placeholder", "id", "disabled"], outputs: ["matChipInputTokenEnd"], exportAs: ["matChipInput", "matChipInputFor"] }, { kind: "directive", type: i10.MatChipRemove, selector: "[matChipRemove]" }, { kind: "component", type: i10.MatChipRow, selector: "mat-chip-row, [mat-chip-row], mat-basic-chip-row, [mat-basic-chip-row]", inputs: ["color", "disabled", "disableRipple", "tabIndex", "editable"], outputs: ["edited"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "pipe", type: DatePipe, name: "date" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'mkh-multi-keywords-highlighter', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        MatButtonModule,
                        MatTooltipModule,
                        MatMenuModule,
                        MatIconModule,
                        MatBadgeModule,
                        NgStyle,
                        NgIf,
                        MatSlideToggleModule,
                        MatFormFieldModule,
                        MatChipsModule,
                        NgFor,
                        AsyncPipe,
                        DatePipe,
                    ], template: "<button\n  mat-icon-button\n  aria-hidden=\"false\"\n  aria-label=\"Multi keywords highlighter\"\n  [color]=\"config.themeColor\"\n  [matTooltip]=\"appName\"\n  [matMenuTriggerFor]=\"menu\"\n  (menuOpened)=\"onOpened()\"\n  (menuClosed)=\"onClosed()\"\n  #menuTrigger=\"matMenuTrigger\"\n  data-testid=\"highlight-keywords-button\"\n>\n  <mat-icon\n    id=\"mh-keyword-count\"\n    aria-hidden=\"false\"\n    aria-label=\"Keywords highlights icon\"\n    [matBadge]=\"keywordCount$\"\n    [matBadgeHidden]=\"keywordCount$ === 0\"\n    matBadgePosition=\"after\"\n    matBadgeColor=\"accent\"\n    svgIcon=\"highlight\"\n  ></mat-icon>\n</button>\n<mat-menu\n  backdropClass=\"mh-backdrop\"\n  class=\"mh-menu\"\n  #menu=\"matMenu\"\n  xPosition=\"before\"\n  yPosition=\"below\"\n>\n  <div\n    class=\"mh-panel\"\n    data-testid=\"highlight-keywords-panel\"\n    (click)=\"$event.stopPropagation()\"\n    [ngStyle]=\"{ minWidth: config.minWidth + 'px' }\"\n  >\n    <div class=\"mh-header mb-[10px]\">\n      <span class=\"mh-text\">\n        <span class=\"mh-app-name\">{{ appName }}</span>\n        <small class=\"mh-version mh-text-tint\">{{ appVersion }}</small>\n      </span>\n      <div class=\"mh-actions\">\n        <ng-container *ngIf=\"config.enableColorPalette\">\n          <button\n            mat-icon-button\n            aria-label=\"Color theme\"\n            [color]=\"config.themeColor\"\n            [matMenuTriggerFor]=\"colorMenu\"\n          >\n            <mat-icon svgIcon=\"color_lens\"></mat-icon>\n          </button>\n          <mat-menu\n            backdropClass=\"mh-backdrop\"\n            class=\"mh-color-palette-menu\"\n            #colorMenu=\"matMenu\"\n            xPosition=\"before\"\n            yPosition=\"below\"\n          >\n            <div (click)=\"$event.stopPropagation()\">\n              <!-- <lib-color-palette></lib-color-palette> -->\n            </div>\n          </mat-menu>\n        </ng-container>\n        <mat-slide-toggle\n          class=\"mh-toggle\"\n          [checked]=\"highlightStauts$\"\n          [matTooltip]=\"config.enableHighlighterTooltip\"\n          [labelPosition]=\"config.toggleLabelPosition\"\n          [color]=\"config.themeColor\"\n          (change)=\"onToggle($event)\"\n          ariaLabel=\"Toggle Highlighter\"\n          data-testid=\"highlight-keywords-slide-toggle\"\n        >\n          <ng-container *ngIf=\"config.enableToggleLabel\">\n            <span class=\"mh-text\">{{ highlightedStautsText$ }}</span>\n          </ng-container>\n        </mat-slide-toggle>\n      </div>\n    </div>\n    <div class=\"mh-body\">\n      <div class=\"mh-content\">\n        <mat-form-field class=\"mh-keyword-list\" appearance=\"fill\">\n          <mat-label>{{ config.keywordsPlaceholder }}</mat-label>\n          <mat-chip-grid aria-label=\"Enter keywords\" #keywordChipList>\n            <mat-chip-row\n              *ngFor=\"let keyword of keywordList$; trackBy: trackById\"\n              selectable=\"true\"\n              [removable]=\"config.removable\"\n              (removed)=\"removeKeyword(keyword)\"\n              [ngStyle]=\"{ 'background-color': keyword?.color }\"\n            >\n              <span\n                matTooltip=\"{{\n                  keyword.name.length >= 36 ? keyword.name : null\n                }}\"\n                class=\"mh-keyword-list-text\"\n                [ngStyle]=\"{ color: config.chipTextColor }\"\n              >\n                {{ keyword.name }}\n              </span>\n              <mat-icon\n                svgIcon=\"clear\"\n                matTooltip=\"Clear\"\n                matChipRemove\n                *ngIf=\"config.removable\"\n                [ngStyle]=\"{ fill: config.chipIconColor }\"\n              >\n              </mat-icon>\n            </mat-chip-row>\n          </mat-chip-grid>\n          <input\n            data-testid=\"mkh-keywords-input\"\n            placeholder=\"{{ config.keywordsPlaceholder }}\"\n            [matChipInputFor]=\"keywordChipList\"\n            [matChipInputSeparatorKeyCodes]=\"separatorKeysCodes\"\n            [matChipInputAddOnBlur]=\"true\"\n            (matChipInputTokenEnd)=\"addKeyword($event)\"\n          />\n        </mat-form-field>\n      </div>\n      <div class=\"mh-footer\">\n        <span class=\"mh-text mh-text-tint\"\n          >Separate by comma [,] or enter key</span\n        >\n        <span class=\"mh-text mh-text-tint\">\n          <ng-container *ngIf=\"config.linkToCopyright; else normalCopyright\">\n            &copy;\n            <a\n              [href]=\"copyrightLink\"\n              class=\"mh-copyright underline\"\n              target=\"_blank\"\n              >{{ copyright }}</a\n            >\n          </ng-container>\n          <ng-template #normalCopyright>\n            <span class=\"mh-copyright\">&copy; {{ copyright }}</span>\n          </ng-template>\n          <span class=\"mh-date\">{{ currentYear | date: 'yyyy' }}</span>\n        </span>\n      </div>\n    </div>\n  </div>\n</mat-menu>\n", styles: ["[role=menu].mat-mdc-menu-panel.mh-menu{min-width:100%;max-width:100%;padding-left:1rem;padding-right:1rem;padding-top:0;padding-bottom:.25rem}.mh-text{font-size:.75rem;line-height:1rem}.mh-text-tint{color:#999}.mh-text-highlighted{display:inline-block;border-radius:3px;padding:0 5px;text-decoration-line:none;--tw-shadow: 0 4px 6px -1px rgb(0 0 0 / .1), 0 2px 4px -2px rgb(0 0 0 / .1);--tw-shadow-colored: 0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.mh-app-name{margin-right:.25rem}.mh-version{font-size:.75rem;line-height:1rem}.mh-panel{display:flex;flex-direction:column}.mh-keyword-list{width:100%}.mh-header{display:flex;flex-direction:row;align-items:center;justify-content:space-between}.mh-actions{display:flex;flex-direction:row;align-items:center;justify-content:flex-end}.mh-body{display:flex;flex-direction:column}.mh-footer{display:flex;align-items:center;justify-content:space-between}.mh-date{margin-left:.25rem}.mh-toggle[ng-reflect-label-position=before] .mh-text{margin-right:.75rem}.mh-toggle[ng-reflect-label-position=after] .mh-text{margin-left:.75rem}a.mh-copyright{color:#999;text-decoration-line:none}a.mh-copyright.underline,a:hover{text-decoration-line:underline}aa.mh-copyright:hover{text-decoration-line:underline}.mat-mdc-chip-input.mat-mdc-form-field-input-control{margin-left:0}.mat-mdc-chip-set .mat-mdc-standard-chip:not(.mdc-evolution-chip--selected) .mdc-evolution-chip__action--primary:before{border-width:0px}\n"] }]
        }], ctorParameters: () => [{ type: NgxMultiKeywordsHighlighterService }, { type: i2.MatIconRegistry }, { type: i3.DomSanitizer }], propDecorators: { menuTrigger: [{
                type: ViewChild,
                args: ['menuTrigger']
            }], initialized: [{
                type: Output
            }], keywordListOutput: [{
                type: Output
            }], highlighted: [{
                type: Output
            }], openMenu: [{
                type: Output
            }], closeMenu: [{
                type: Output
            }] } });

class NgxMultiKeywordsHighlighterModule {
    // constructor(
    //   @Optional() @SkipSelf() parentModule?: NgxMultiKeywordsHighlighterModule
    // ) {
    //   if (parentModule) {
    //     throw new Error(
    //       'NgxMultiKeywordsHighlighterModule is already loaded. Import it in the AppModule only'
    //     );
    //   }
    // }
    static forRoot(config) {
        return {
            ngModule: NgxMultiKeywordsHighlighterModule,
            providers: [
                {
                    provide: MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN,
                    useValue: config,
                },
            ],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MaterialComponentsModule,
            NgxMultiKeywordsHighlighterComponent], exports: [NgxMultiKeywordsHighlighterComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterModule, providers: [NgxMultiKeywordsHighlighterService], imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MaterialComponentsModule,
            NgxMultiKeywordsHighlighterComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: NgxMultiKeywordsHighlighterModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MaterialComponentsModule,
                        NgxMultiKeywordsHighlighterComponent,
                    ],
                    providers: [NgxMultiKeywordsHighlighterService],
                    exports: [NgxMultiKeywordsHighlighterComponent],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { COLOR, COLOR_PALETTE, LABEL_POSITION, LibConfig, MATERIAL_COLOR, MULTI_KEYWORDS_HIGHLIGHTER_CONFIG_TOKEN, MultiKeywordsHighlighterConstants, NAME_SPACE, NgxMultiKeywordsHighlighterComponent, NgxMultiKeywordsHighlighterModule, NgxMultiKeywordsHighlighterService, defaultConfig };
//# sourceMappingURL=amfrontender-ngx-multi-keywords-highlighter.mjs.map
