import { EventEmitter, OnInit } from '@angular/core';
import { MatChipInputEvent } from '@angular/material/chips';
import { MatIconRegistry } from '@angular/material/icon';
import { MatSlideToggleChange } from '@angular/material/slide-toggle';
import { DomSanitizer } from '@angular/platform-browser';
import { MatMenuTrigger } from '@angular/material/menu';
import { IKeyword, MultiKeywordsHighlighterConfig } from './core';
import { NgxMultiKeywordsHighlighterService } from './ngx-multi-keywords-highlighter.service';
import * as i0 from "@angular/core";
export declare class NgxMultiKeywordsHighlighterComponent implements OnInit {
    private readonly mkhService;
    private readonly iconRegistry;
    private readonly sanitizer;
    menuTrigger: MatMenuTrigger;
    /**
     * Output event for initialized event
     * @returns boolean
     */
    initialized: EventEmitter<boolean>;
    /**
     * Output event for keywords list
     * @returns IKeyword[]
     */
    keywordListOutput: EventEmitter<IKeyword[]>;
    /**
     * Output event for highlighted status
     * @returns boolean
     */
    highlighted: EventEmitter<boolean>;
    /**
     * Output event for on Open Menu
     * @returns boolean
     */
    openMenu: EventEmitter<boolean>;
    /**
     * Output event for on Close Menu
     * @returns boolean
     */
    closeMenu: EventEmitter<boolean>;
    /**
     * Copyright year
     */
    readonly currentYear: Date;
    /**
     * Separator keys codes
     */
    readonly separatorKeysCodes: number[];
    /**
     * Keyword quantity shows on badge
     */
    keywordQuantity$: import("@angular/core").WritableSignal<number>;
    constructor(mkhService: NgxMultiKeywordsHighlighterService, iconRegistry: MatIconRegistry, sanitizer: DomSanitizer);
    ngOnInit(): void;
    /**
     * Copyright
     */
    get copyright(): string;
    /**
     * Copyright link
     */
    get copyrightLink(): string;
    /**
     * Library name
     */
    get appName(): string;
    /**
     * Library version
     */
    get appVersion(): string;
    /**
     * Library configuration
     */
    get config(): MultiKeywordsHighlighterConfig;
    /**
     * Highlighted stauts text
     */
    get highlightedStautsText$(): string;
    /**
     * Highlight status
     */
    get highlightStauts$(): boolean;
    /**
     * Keyword list
     */
    get keywordList$(): IKeyword[];
    /**
     * Keyword counter
     */
    get keywordCount$(): number;
    /**
     * On keywords highlighter opened event
     */
    onOpened(): void;
    /**
     * On keywords highlighter closed event
     */
    onClosed(): void;
    /**
     * On check the highlighter checkbox
     * @param event MatSlideToggleChange
     */
    onToggle(event: MatSlideToggleChange): void;
    trackById(index: number, keyword: IKeyword): number | undefined;
    /**
     * Add a keyword
     * @param event MatChipInputEvent
     */
    addKeyword(event: MatChipInputEvent): void;
    /**
     * Remove a keyword from the list
     * @param keyword Keyword to remove
     */
    removeKeyword(keyword: IKeyword): void;
    /**
     * Get a random color from the color palette
     */
    private getRandomColor;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxMultiKeywordsHighlighterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxMultiKeywordsHighlighterComponent, "mkh-multi-keywords-highlighter", never, {}, { "initialized": "initialized"; "keywordListOutput": "keywordListOutput"; "highlighted": "highlighted"; "openMenu": "openMenu"; "closeMenu": "closeMenu"; }, never, never, true, never>;
}
